BOK_META_DATA = "BOK_META_DATA"
BOK_STAT_DATA = "BOK_STAT_DATA"
BOK_STAT_CODE_DATA = "BOK_STAT_CODE_DATA"
QUANDL_META_DATA = "QUANDL_META_DATA"
QUANDL_STAT_DATA = "QUANDL_STAT_DATA"
DAILY_STOCK_DATA = "DAILY_STOCK_DATA"
DAILY_STOCK_DATA_RESULT = "DAILY_STOCK_DATA_RESULT"
WORKER_SUCCESS = "WORKER_SUCCESS"
YEARLY_REPORT = "사업보고서"
SEPTEMBER_REPORT = "9월분기보고서"
MARCH_REPORT = "3월분기보고서"
QUARTER_REPORT = "분기보고서"
SEMINUAL_REPORT = "반기보고서"
CONNECTED_FINANCIAL_STATEMENTS = "CONNECTED_FINANCIAL_STATEMENTS"
NORMAL_FINANCIAL_STATEMENTS = "NORMAL_FINANCIAL_STATEMENTS"
